# Changelog

## 0.1.0-alpha.8 (2024-07-10)

Full Changelog: [v0.1.0-alpha.7...v0.1.0-alpha.8](https://github.com/propulsion-ai/propulsionai-python/compare/v0.1.0-alpha.7...v0.1.0-alpha.8)

### Features

* add **/.DS_Store ([4808613](https://github.com/propulsion-ai/propulsionai-python/commit/4808613c64ec3014c94f63cab8de50f4b806978b))
* **api:** OpenAPI spec update via Stainless API ([#34](https://github.com/propulsion-ai/propulsionai-python/issues/34)) ([7423c8a](https://github.com/propulsion-ai/propulsionai-python/commit/7423c8a720f641986db2a0d2bc6da05baff76643))
* fix lint ([70f4730](https://github.com/propulsion-ai/propulsionai-python/commit/70f473069e06c494d8cdf11963ea3ab86b8b131c))
* fix model endpoints manually ([b7039ed](https://github.com/propulsion-ai/propulsionai-python/commit/b7039ed1d96babc9d1dbc918f5a346c7d51c9682))
* fix ModelEpResponse ([ebf99be](https://github.com/propulsion-ai/propulsionai-python/commit/ebf99bef0ce027b98bdc73b754a115ee888d21a6))
* fix test ([2a4295e](https://github.com/propulsion-ai/propulsionai-python/commit/2a4295ede5c375f3d810b9d6b2f862b27a6ff049))
* fix test ([1670763](https://github.com/propulsion-ai/propulsionai-python/commit/167076335eb8be90d4393b1b5b317670db5e82b3))
* fix typechecking and imports ([b38ff7b](https://github.com/propulsion-ai/propulsionai-python/commit/b38ff7b7bc4105be89921a924e81546fad672be7))
* lint ([056bc69](https://github.com/propulsion-ai/propulsionai-python/commit/056bc6909649bb75533b9240c65d82dfe0397467))

## 0.1.0-alpha.7 (2024-07-09)

Full Changelog: [v0.1.0-alpha.6...v0.1.0-alpha.7](https://github.com/propulsion-ai/propulsionai-python/compare/v0.1.0-alpha.6...v0.1.0-alpha.7)

### Features

* **api:** OpenAPI spec update via Stainless API ([#23](https://github.com/propulsion-ai/propulsionai-python/issues/23)) ([828e954](https://github.com/propulsion-ai/propulsionai-python/commit/828e954676813291c760ff43c3b69718661d2af7))
* **api:** OpenAPI spec update via Stainless API ([#25](https://github.com/propulsion-ai/propulsionai-python/issues/25)) ([7c77e0f](https://github.com/propulsion-ai/propulsionai-python/commit/7c77e0f2d32c04b0eab805ffac25f17b8cd18a7f))
* **api:** OpenAPI spec update via Stainless API ([#31](https://github.com/propulsion-ai/propulsionai-python/issues/31)) ([c6ee599](https://github.com/propulsion-ai/propulsionai-python/commit/c6ee5998a353045b5c2dab7a429b595e6c90ea1c))
* **api:** OpenAPI spec update via Stainless API ([#33](https://github.com/propulsion-ai/propulsionai-python/issues/33)) ([56bbd89](https://github.com/propulsion-ai/propulsionai-python/commit/56bbd894fe491f40dcfe9c2f7d6727b5d6651338))

## 0.1.0-alpha.6 (2024-06-12)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/propulsion-ai/propulsionai-python/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Features

* fix linting errors ([ea7eefc](https://github.com/propulsion-ai/propulsionai-python/commit/ea7eefc6a392a0838fdbc78db4cc31e5041655eb))
* git pull origin release-please--branches--main--changes--next ([42222d9](https://github.com/propulsion-ai/propulsionai-python/commit/42222d92088604a3a0cad062968c257c8addf73a))

## 0.1.0-alpha.5 (2024-06-12)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/propulsion-ai/propulsionai-python/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** OpenAPI spec update via Stainless API ([#18](https://github.com/propulsion-ai/propulsionai-python/issues/18)) ([fdee4ba](https://github.com/propulsion-ai/propulsionai-python/commit/fdee4bad04a2d40d2325e75b1bbd7285647d2083))

## 0.1.0-alpha.4 (2024-06-12)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/propulsion-ai/propulsionai-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** OpenAPI spec update via Stainless API ([#15](https://github.com/propulsion-ai/propulsionai-python/issues/15)) ([1b44c0f](https://github.com/propulsion-ai/propulsionai-python/commit/1b44c0f702364adcaee131b85efa107414c902e7))
* **api:** OpenAPI spec update via Stainless API ([#16](https://github.com/propulsion-ai/propulsionai-python/issues/16)) ([d56125f](https://github.com/propulsion-ai/propulsionai-python/commit/d56125fc8d38e10a8a1883b806e97bd7868e0a74))

## 0.1.0-alpha.3 (2024-06-11)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/propulsion-ai/propulsionai-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** OpenAPI spec update via Stainless API ([#9](https://github.com/propulsion-ai/propulsionai-python/issues/9)) ([e046213](https://github.com/propulsion-ai/propulsionai-python/commit/e046213a1c0d4364061c88a07c7423fb464c1486))
* **api:** update via SDK Studio ([#11](https://github.com/propulsion-ai/propulsionai-python/issues/11)) ([663b080](https://github.com/propulsion-ai/propulsionai-python/commit/663b080ad6c60e2048e8d4e3f26f7760aa0e7ef3))
* **api:** update via SDK Studio ([#12](https://github.com/propulsion-ai/propulsionai-python/issues/12)) ([84db911](https://github.com/propulsion-ai/propulsionai-python/commit/84db9117c6f879aa4e33f1c86b2c18c86e8193fc))

## 0.1.0-alpha.2 (2024-06-10)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/propulsion-ai/propulsionai-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([#1](https://github.com/propulsion-ai/propulsionai-python/issues/1)) ([8d1a074](https://github.com/propulsion-ai/propulsionai-python/commit/8d1a0742706ba9dd3726d98e7259fc93de858342))


### Chores

* configure new SDK language ([7eb1613](https://github.com/propulsion-ai/propulsionai-python/commit/7eb1613247cdd64fdffd473b46353176f288344d))

## 0.1.0-alpha.1 (2024-06-10)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/propulsion-ai/propulsionai-node/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([#1](https://github.com/propulsion-ai/propulsionai-node/issues/1)) ([28180b4](https://github.com/propulsion-ai/propulsionai-node/commit/28180b4c134fc95260bb5cc4e41b7da9132f25d7))


### Chores

* configure new SDK language ([7eb1613](https://github.com/propulsion-ai/propulsionai-node/commit/7eb1613247cdd64fdffd473b46353176f288344d))
